parade.connection package
=========================

Submodules
----------

parade.connection.fake module
-----------------------------

.. automodule:: parade.connection.fake
    :members:
    :undoc-members:
    :show-inheritance:

parade.connection.localfile module
----------------------------------

.. automodule:: parade.connection.localfile
    :members:
    :undoc-members:
    :show-inheritance:

parade.connection.rdb module
----------------------------

.. automodule:: parade.connection.rdb
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: parade.connection
    :members:
    :undoc-members:
    :show-inheritance:
